import React, { useState, useEffect } from "react";
import { Navigate } from "react-router-dom";

const CandidacyForm = () => {
  const [students, setStudents] = useState([]);
  const [stages, setStages] = useState([]);
  const [supervisors, setSupervisors] = useState([]); // Load supervisors

  const [formData, setFormData] = useState({
    studentId: "",
    stageId: "",
    univSupervisorId: "",
    comment: "", // ✅ Ajout du champ comment
  });
  

  useEffect(() => {
    fetch("http://localhost:8080/api/students")
      .then((res) => res.json())
      .then((data) => setStudents(data));

    fetch("http://localhost:8080/api/stages")
      .then((res) => res.json())
      .then((data) => setStages(data));

    fetch("http://localhost:8080/api/univsupervisors") // Load supervisors
      .then((res) => res.json())
      .then((data) => setSupervisors(data));
  }, []);

  const handleChange = (e) => {
    setFormData({ ...formData, [e.target.name]: e.target.value });
  };

  const handleSubmit = (e) => {
    e.preventDefault();
  
    const candidacyData = {
      student: { id: formData.studentId },
      stage: { id: formData.stageId },
      univSupervisor: { id: formData.univSupervisorId },
      comment: formData.comment || "Aucun commentaire fourni", // ✅ Ajout du champ commentaire
    };
  
    console.log("📌 Sending Candidacy Data:", JSON.stringify(candidacyData, null, 2)); // Debug
  
    fetch("http://localhost:8080/api/candidacies/add", {
      method: "POST",
      headers: { "Content-Type": "application/json" },
      credentials: "include",
      body: JSON.stringify(candidacyData),
    })
      .then((res) => {
        console.log("📌 Response status:", res.status);
        return res.json();
      })
      .then((data) => {
        console.log("✅ Candidacy added successfully:", data);
        alert("Candidature ajoutée avec succès !");
      })
      .catch((err) => console.error("❌ Error:", err.message));
  };
  
  // Handle cancel button
  const handleCancel = () => {
    Navigate("/candidatures"); // Redirect back to candidacy list
  };

  return (
    <div className="container mt-4">
      <h2>Ajouter une Candidature</h2>
      <form onSubmit={handleSubmit}>
        {/* Select Student */}
        <div className="mb-3">
          <label className="form-label">Étudiant:</label>
          <select
            className="form-control"
            name="studentId"
            value={formData.studentId}
            onChange={handleChange}
            required
          >
            <option value="">Sélectionnez un étudiant</option>
            {students.map((student) => (
              <option key={student.id} value={student.id}>
                {student.firstname} {student.lastname}
              </option>
            ))}
          </select>
        </div>

        {/* Select Stage */}
        <div className="mb-3">
          <label className="form-label">Stage:</label>
          <select
            className="form-control"
            name="stageId"
            value={formData.stageId}
            onChange={handleChange}
            required
          >
            <option value="">Sélectionnez un stage</option>
            {stages.map((stage) => (
              <option key={stage.id} value={stage.id}>
                {stage.name} - {stage.description}
              </option>
            ))}
          </select>
        </div>
        <div className="mb-3">
          <label className="form-label">Commentaire:</label>
          <textarea
            className="form-control"
            name="comment"
            value={formData.comment}
            onChange={handleChange}
          />
        </div>

        {/* Select UnivSupervisor */}
        <div className="mb-3">
          <label className="form-label">Superviseur Universitaire:</label>
          <select
            className="form-control"
            name="univSupervisorId"
            value={formData.univSupervisorId}
            onChange={handleChange}
            required
          >
            <option value="">Sélectionnez un superviseur</option>
            {supervisors.map((supervisor) => (
              <option key={supervisor.id} value={supervisor.id}>
                {supervisor.name}
              </option>
            ))}
          </select>
        </div>

        {/* Submit Button */}
        <div className="d-flex gap-2">
            <button type="submit" className="btn btn-primary">
            Ajouter Candidature
            </button>
            <button type="button" className="btn btn-secondary" onClick={handleCancel}>Annuler</button>
        </div>
      </form>
    </div>
  );
};

export default CandidacyForm;
