import React, { useState, useEffect } from "react";
import { useParams, useNavigate } from "react-router-dom";

const CandidacyFormPrerempli = () => {
  const { stageId } = useParams(); // ✅ Get stageId from URL
  const navigate = useNavigate();

  const [supervisors, setSupervisors] = useState([]);
  const [formData, setFormData] = useState({
    studentId: "",
    stageId: stageId || "", // ✅ Pre-fill with stageId from URL
    univSupervisorId: "",
    comment: "",
  });

  /** 🔹 Load the logged-in student from localStorage */
  useEffect(() => {
    const storedUser = JSON.parse(localStorage.getItem("user"));
    if (storedUser && storedUser.id) {
      setFormData((prevFormData) => ({
        ...prevFormData,
        studentId: storedUser.id, // ✅ Automatically set student ID
      }));
    }
  }, []);

  /** 🔹 Fetch available university supervisors */
  useEffect(() => {
    fetch("http://localhost:8080/api/univsupervisors")
      .then((res) => res.json())
      .then((data) => setSupervisors(data))
      .catch((err) => console.error("❌ Error loading supervisors:", err));
  }, []);

  const handleChange = (e) => {
    setFormData({ ...formData, [e.target.name]: e.target.value });
  };

  const handleSubmit = (e) => {
    e.preventDefault();

    const candidacyData = {
      student: { id: formData.studentId },
      stage: { id: formData.stageId },
      univSupervisor: { id: formData.univSupervisorId },
      comment: formData.comment || "Aucun commentaire fourni",
    };

    console.log("📌 Sending Candidacy Data:", JSON.stringify(candidacyData, null, 2));

    fetch("http://localhost:8080/api/candidacies/add", {
      method: "POST",
      headers: { "Content-Type": "application/json" },
      credentials: "include",
      body: JSON.stringify(candidacyData),
    })
      .then((res) => {
        console.log("📌 Response status:", res.status);
        return res.json();
      })
      .then((data) => {
        console.log("✅ Candidacy added successfully:", data);
        alert("Candidature ajoutée avec succès !");
        navigate("/stages");
      })
      .catch((err) => console.error("❌ Error:", err.message));
  };

  return (
    <div className="container mt-4">
      <h2>Ajouter ma Candidature</h2>
      <form onSubmit={handleSubmit}>
        {/* ✅ Student (pre-filled, non-editable) */}
        <div className="mb-3">
          <label className="form-label">Étudiant:</label>
          <input
            type="text"
            className="form-control"
            value={`${localStorage.getItem("username") || ""} ${localStorage.getItem("familyname") || ""}`}
            disabled
          />
        </div>

        {/* ✅ Stage (pre-filled, non-editable) */}
        <div className="mb-3">
          <label className="form-label">Stage:</label>
          <input
            type="text"
            className="form-control"
            value={`Stage ID: ${formData.stageId}`}
            disabled
          />
        </div>
        <div className="mb-3">
        <label className="form-label">Commentaire:</label>
        <textarea
            className="form-control"
            name="comment"
            value={formData.comment}
            onChange={handleChange}
        />
        </div>

        {/* Select UnivSupervisor */}
        <div className="mb-3">
          <label className="form-label">Superviseur Universitaire:</label>
          <select
            className="form-control"
            name="univSupervisorId"
            value={formData.univSupervisorId}
            onChange={handleChange}
            required
          >
            <option value="">Sélectionnez un superviseur</option>
            {supervisors.map((supervisor) => (
              <option key={supervisor.id} value={supervisor.id}>
                {supervisor.name}
              </option>
            ))}
          </select>
        </div>

        <div className="d-flex gap-2">
          <button type="submit" className="btn btn-primary">📩 Postuler</button>
          <button type="button" className="btn btn-secondary" onClick={() => navigate("/stages")}>Annuler</button>
        </div>
      </form>
    </div>
  );
};

export default CandidacyFormPrerempli;
