import React, { useState, useEffect } from "react";
import { Link, useNavigate } from "react-router-dom";

function CandidacyList() {
  const [candidacies, setCandidacies] = useState([]);
  const navigate = useNavigate();

  useEffect(() => {
    fetch("http://localhost:8080/api/candidacies")
      .then((res) => res.json())
      .then((data) => setCandidacies(data))
      .catch((err) => console.error("Erreur lors de la récupération :", err));
  }, []);

  // Function to delete candidacy
  const handleDelete = (id) => {
    if (window.confirm("Êtes-vous sûr de vouloir supprimer cette candidature ?")) {
      fetch(`http://localhost:8080/api/candidacies/delete/${id}`, { method: "DELETE" })
        .then(() => {
          alert("Candidature supprimée avec succès !");
          setCandidacies(candidacies.filter((candidacy) => candidacy.id !== id));
        })
        .catch((err) => console.error("Erreur lors de la suppression :", err));
    }
  };

  return (
    <div className="container mt-4">
      <h2>Liste des Candidatures</h2>
      <div>
        <Link to="/ajouter-candidature" className="btn btn-success mt-3">
        Ajouter une candidature
        </Link>
      </div>
      <br />
      <table className="table table-striped">
        <thead>
          <tr>
            <th>ID</th>
            <th>Étudiant</th>
            <th>Stage</th>
            <th>Superviseur Universitaire</th>
            <th>État de la Demande</th>
            <th>Statut Accepté</th>
            <th>Commentaire</th>
            <th>Actions</th> {/* Added column for buttons */}
          </tr>
        </thead>
        <tbody>
          {candidacies.map((candidacy) => (
            <tr key={candidacy.id}>
              <td>{candidacy.id}</td>
              <td>{candidacy.student?.firstname} {candidacy.student?.lastname}</td>
              <td>{candidacy.stage?.name}</td>
              <td>{candidacy.univSupervisor?.name || "Non attribué"}</td>
              <td>{candidacy.requestState}</td>
              <td>{candidacy.acceptedState}</td>
              <td>{candidacy.comment || "Pas de commentaire"}</td> 
              <td>
                
                <button 
                  className="btn btn-warning btn-sm me-2"
                  onClick={() => navigate(`/modifier-candidature/${candidacy.id}`)}
                >
                  Modifier
                </button>
                <button 
                  className="btn btn-danger btn-sm"
                  onClick={() => handleDelete(candidacy.id)}
                >
                  Supprimer
                </button>
              </td>
            </tr>
          ))}
        </tbody>
      </table>
    </div>
  );
}

export default CandidacyList;
