import React, { useState, useEffect } from "react";
import { useParams, useNavigate } from "react-router-dom";

function UpdateCandidacyForm() {
  const { id } = useParams();
  const navigate = useNavigate();
  
  // State for candidacy
  const [candidacy, setCandidacy] = useState({
    student: { id: "", firstname: "", lastname: "" },
    stage: { id: "", name: "" },
    univSupervisor: { id: "", name: "" },
    requestState: "",
    acceptedState: "",
  });

  // State for dropdown lists
  const [students, setStudents] = useState([]);
  const [stages, setStages] = useState([]);
  const [univSupervisors, setUnivSupervisors] = useState([]);

  // Fetch existing candidacy details
  useEffect(() => {
    fetch(`http://localhost:8080/api/candidacies/${id}`)
      .then((res) => res.json())
      .then((data) => setCandidacy(data))
      .catch((err) => console.error("Erreur lors de la récupération :", err));

    // Fetch dropdown options
    fetch("http://localhost:8080/api/students")
      .then((res) => res.json())
      .then((data) => setStudents(data));

    fetch("http://localhost:8080/api/stages")
      .then((res) => res.json())
      .then((data) => setStages(data));

    fetch("http://localhost:8080/api/univsupervisors")
      .then((res) => res.json())
      .then((data) => setUnivSupervisors(data));
  }, [id]);

  // Handle change for dropdowns
  const handleChange = (e) => {
    setCandidacy({ ...candidacy, [e.target.name]: e.target.value });
  };

  // Handle dropdown selection
  const handleSelectChange = (e) => {
    const { name, value } = e.target;
    setCandidacy({
      ...candidacy,
      [name]: { id: value },
    });
  };

  // Submit updated candidacy
  const handleSubmit = (e) => {
    e.preventDefault();

    fetch(`http://localhost:8080/api/candidacies/update/${id}`, {
      method: "PUT",
      headers: { "Content-Type": "application/json" },
      body: JSON.stringify(candidacy),
    })
      .then(() => {
        alert("Candidature mise à jour avec succès !");
        navigate("/candidatures");
      })
      .catch((err) => console.error("Erreur lors de la mise à jour :", err));
  };

  // Handle cancel button
  const handleCancel = () => {
    navigate("/candidatures"); // Redirect back to candidacy list
  };

  return (
    <div className="container mt-4">
      <h2>Modifier la Candidature</h2>
      <form onSubmit={handleSubmit}>

        {/* Étudiant Dropdown */}
        <div className="mb-3">
          <label className="form-label">Étudiant</label>
          <select
            className="form-control"
            name="student"
            value={candidacy.student?.id || ""}
            onChange={handleSelectChange}
          >
            <option value="">Sélectionner un étudiant</option>
            {students.map((student) => (
              <option key={student.id} value={student.id}>
                {student.firstname} {student.lastname}
              </option>
            ))}
          </select>
        </div>

        {/* Stage Dropdown */}
        <div className="mb-3">
          <label className="form-label">Stage</label>
          <select
            className="form-control"
            name="stage"
            value={candidacy.stage?.id || ""}
            onChange={handleSelectChange}
          >
            <option value="">Sélectionner un stage</option>
            {stages.map((stage) => (
              <option key={stage.id} value={stage.id}>
                {stage.name}
              </option>
            ))}
          </select>
        </div>

        {/* Superviseur Universitaire Dropdown */}
        <div className="mb-3">
          <label className="form-label">Superviseur Universitaire</label>
          <select
            className="form-control"
            name="univSupervisor"
            value={candidacy.univSupervisor?.id || ""}
            onChange={handleSelectChange}
          >
            <option value="">Sélectionner un superviseur</option>
            {univSupervisors.map((supervisor) => (
              <option key={supervisor.id} value={supervisor.id}>
                {supervisor.name}
              </option>
            ))}
          </select>
        </div>

        {/* État de la Demande Dropdown */}
        <div className="mb-3">
          <label className="form-label">État de la Demande</label>
          <select
            className="form-control"
            name="requestState"
            value={candidacy.requestState}
            onChange={handleChange}
          >
            <option value="FirstRequest">Première Demande</option>
            <option value="Accepted">Accepté</option>
            <option value="Declined">Refusé</option>
          </select>
        </div>

        {/* Statut Accepté Dropdown */}
        <div className="mb-3">
          <label className="form-label">Statut Accepté</label>
          <select
            className="form-control"
            name="acceptedState"
            value={candidacy.acceptedState}
            onChange={handleChange}
          >
            <option value="wait">En attente</option>
            <option value="inProgress">En cours</option>
            <option value="terminated">Terminé</option>
          </select>
        </div>

        {/* Buttons: Update & Cancel */}
        <div className="d-flex gap-2">
          <button type="submit" className="btn btn-success">Mettre à jour</button>
          <button type="button" className="btn btn-secondary" onClick={handleCancel}>Annuler</button>
        </div>
        
      </form>
    </div>
  );
}

export default UpdateCandidacyForm;
