import React, { useState, useEffect } from "react";
import { Link, useNavigate } from "react-router-dom";

function EnterpriseList() {
  const [enterprises, setEnterprises] = useState([]);
  const navigate = useNavigate();

  // Fetch Enterprises
  useEffect(() => {
    fetchEnterprises();
  }, []);

  const fetchEnterprises = () => {
    fetch("http://localhost:8080/api/enterprises")
      .then((response) => response.json())
      .then((data) => setEnterprises(data))
      .catch((error) => console.error("Error fetching enterprises:", error));
  };

  // Handle Delete
  const handleDelete = (id) => {
    if (window.confirm("Voulez-vous vraiment supprimer cette entreprise ?")) {
      fetch(`http://localhost:8080/api/enterprises/delete/${id}`, {
        method: "DELETE",
      })
        .then(() => {
          alert("Entreprise supprimée avec succès !");
          fetchEnterprises(); // Refresh list after delete
        })
        .catch((error) => console.error("Error deleting enterprise:", error));
    }
  };

  // Handle Update
  const handleUpdate = (id) => {
    navigate(`/modifier-entreprise/${id}`);
  };

  return (
    <div className="container mt-4">
      <h2 className="mb-4">Liste des Entreprises</h2>
      <div>
        <Link to="/ajouter-entreprise" className="btn btn-success mt-3">
        Ajouter une entreprise
        </Link>
      </div>
      <br />
      <table className="table table-striped table-hover">
        <thead className="table-primary">
          <tr>
            <th>ID</th>
            <th>Nom</th>
            <th>Adresse</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {enterprises.map((enterprise) => (
            <tr key={enterprise.id}>
              <td>{enterprise.id}</td>
              <td>{enterprise.name}</td>
              <td>{enterprise.address}</td>
              <td>
                <button
                  className="btn btn-warning btn-sm me-2"
                  onClick={() => handleUpdate(enterprise.id)}
                >
                  Modifier
                </button>
                <button
                  className="btn btn-danger btn-sm"
                  onClick={() => handleDelete(enterprise.id)}
                >
                  Supprimer
                </button>
              </td>
            </tr>
          ))}
        </tbody>
      </table>
    </div>
  );
}

export default EnterpriseList;
