import { useState, useEffect } from "react";
import { useNavigate } from "react-router-dom";

const Login = () => {
  const [username, setUsername] = useState("");
  const [password, setPassword] = useState("");
  const [error, setError] = useState("");
  const navigate = useNavigate();

  useEffect(() => {
    const token = localStorage.getItem("token");
    if (token) {
      navigate("/"); // Redirect if already logged in
    }
  }, [navigate]);

  const handleLogin = async (e) => {
    e.preventDefault();
  
    try {
        const response = await fetch("http://localhost:8080/api/auth/login", {
            method: "POST",
            headers: {
                "Content-Type": "application/json",
            },
            body: JSON.stringify({ username, password }),
        });

        if (!response.ok) {
            throw new Error("Invalid credentials");
        }

        const data = await response.json();
        console.log("✅ Login successful!", data);

        // Assurer que l'ID est bien récupéré
        if (!data.id) {
            throw new Error("User ID is missing from response!");
        }

        // Stocke correctement les informations utilisateur
        localStorage.setItem("token", "dummy-token"); 
        localStorage.setItem("roles", JSON.stringify(data.roles));
        localStorage.setItem("user", JSON.stringify({ 
            id: data.id, // Ajout de l'ID ici 
            username: data.username, 
            familyname: data.familyname 
        }));

        navigate("/"); // Redirect after login
        window.location.reload(); //  Rafraîchir la page pour mettre à jour la NavBar

    } catch (error) {
        console.error("❌ Login failed:", error.message);
        setError("Invalid username or password");
    }
};

  


  return (
    <div style={{ textAlign: "center", marginTop: "50px" }}>
      <h2>Login</h2>
      <form onSubmit={handleLogin}>
        <div>
          <input
            type="text"
            placeholder="Username"
            value={username}
            onChange={(e) => setUsername(e.target.value)}
            required
          />
        </div>
        <div>
          <input
            type="password"
            placeholder="Password"
            value={password}
            onChange={(e) => setPassword(e.target.value)}
            required
          />
        </div>
        {error && <p style={{ color: "red" }}>{error}</p>}
        <button type="submit">Login</button>
      </form>
    </div>
  );
};

export default Login;
