import React, { useEffect, useState } from "react";
import { Link } from "react-router-dom";

function Navbar() {
  const [roles, setRoles] = useState([]);
  const [user, setUser] = useState({ username: "", familyname: "" });

  useEffect(() => {
    // ✅ Get roles from localStorage
    const storedRoles = localStorage.getItem("roles");
    if (storedRoles) {
      try {
        setRoles(JSON.parse(storedRoles));
      } catch (error) {
        console.error("❌ Error parsing roles from localStorage", error);
        setRoles([]); // Fallback if parsing fails
      }
    }

    // ✅ Get user info (username & familyname)
    const storedUser = localStorage.getItem("user");
    if (storedUser) {
      try {
        setUser(JSON.parse(storedUser));
      } catch (error) {
        console.error("❌ Error parsing user data from localStorage", error);
        setUser({ username: "", familyname: "" }); // Fallback if parsing fails
      }
    }
  }, []);

  // 🔥 Function to check if user has a specific role
  const hasRole = (role) => roles.includes(role);

  return (
    <nav className="navbar navbar-expand-lg navbar-dark bg-primary">
      <div className="container">
        <Link className="navbar-brand" to="/">🏫 Gestion Stages</Link>
        <button
          className="navbar-toggler"
          type="button"
          data-bs-toggle="collapse"
          data-bs-target="#navbarNav"
          aria-controls="navbarNav"
          aria-expanded="false"
          aria-label="Toggle navigation"
        >
          <span className="navbar-toggler-icon"></span>
        </button>
        <div className="collapse navbar-collapse" id="navbarNav">
          <ul className="navbar-nav ms-auto">


            {/* ✅ Display Logged-in User Info */}
            {user.username && (
              <li className="nav-item">
                <span className="nav-link">👤 {user.username} {user.familyname}</span>
              </li>
            )}

            {/* 📚 Stages */}
            {(hasRole("ROLE_ETUDIANT") || hasRole("ROLE_ENTREPRISE") || hasRole("ROLE_SUPERVISEUR") || hasRole("ROLE_ADMIN")) && (
              <li className="nav-item dropdown">
                <a className="nav-link dropdown-toggle" href="#" id="stagesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                  📚 Stages
                </a>
                <ul className="dropdown-menu" aria-labelledby="stagesDropdown">
                  <li><Link className="dropdown-item" to="/stages">📜 Liste des Stages</Link></li>
                  {(hasRole("ROLE_ENTREPRISE") || hasRole("ROLE_SUPERVISEUR") || hasRole("ROLE_ADMIN")) && (
                    <li><Link className="dropdown-item" to="/ajouter-stage">➕ Ajouter un Stage</Link></li>
                  )}
                </ul>
              </li>
            )}

            {/* 👨‍🎓 Étudiants */}
            {(hasRole("ROLE_ADMIN") || hasRole("ROLE_SUPERVISEUR") || hasRole("ROLE_ADMIN")) && (
              <li className="nav-item dropdown">
                <a className="nav-link dropdown-toggle" href="#" id="etudiantsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                  👨‍🎓 Étudiants
                </a>
                <ul className="dropdown-menu" aria-labelledby="etudiantsDropdown">
                  {/* Everyone with ETUDIANT, SUPERVISEUR, ADMIN can see the list */}
                  <li><Link className="dropdown-item" to="/etudiants">📜 Liste des Étudiants</Link></li>

                  {/* BUT ONLY ADMIN CAN ADD */}
                  {hasRole("ROLE_ADMIN") && (
                    <>

                      <li><Link className="dropdown-item" to="/ajouter-etudiant">➕ Ajouter un Étudiant</Link></li>
                    </>
                  )}
                </ul>
              </li>
            )}

            {/* 🏢 Entreprises */}
            {(hasRole("ROLE_ENTREPRISE") || hasRole("ROLE_ADMIN")) && (
              <li className="nav-item dropdown">
                <a className="nav-link dropdown-toggle" href="#" id="entreprisesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                  🏢 Entreprises
                </a>
                <ul className="dropdown-menu" aria-labelledby="entreprisesDropdown">
                  <li><Link className="dropdown-item" to="/entreprises">📜 Liste des Entreprises</Link></li>
                  {hasRole("ROLE_ADMIN") && (
                    <li><Link className="dropdown-item" to="/ajouter-entreprise">➕ Ajouter une Entreprise</Link></li>)}
                  
                </ul>
              </li>
            )}

            {/* 📝 Candidatures */}
            {(hasRole("ROLE_ADMIN") || hasRole("ROLE_SUPERVISEUR")) && (
              <li className="nav-item dropdown">
                <a className="nav-link dropdown-toggle" href="#" id="candidaturesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                  📝 Candidatures
                </a>
                <ul className="dropdown-menu" aria-labelledby="candidaturesDropdown">
                 
                  
                    <li><Link className="dropdown-item" to="/candidatures">📜 Liste des Candidatures</Link></li>
                  
                  
                  <li><Link className="dropdown-item" to="/ajouter-candidature">➕ Ajouter une Candidature</Link></li>
                
                </ul>
              </li>
            )}


            {/* 👨‍🏫 Superviseurs (Admin Only) */}
            {hasRole("ROLE_ADMIN") && (
              <li className="nav-item dropdown">
                <a className="nav-link dropdown-toggle" href="#" id="superviseursDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                  👨‍🏫 Superviseurs
                </a>
                <ul className="dropdown-menu" aria-labelledby="superviseursDropdown">
                  <li><Link className="dropdown-item" to="/superviseurs">📜 Liste des Superviseurs</Link></li>
                  {hasRole("ROLE_ADMIN") && (
                  <li><Link className="dropdown-item" to="/ajouter-univsuperviseur">➕ Ajouter un Superviseur</Link></li>)}
                </ul>
              </li>
            )}

            {/* 🔑 Authentification */}
            <li className="nav-item">
              <Link className="nav-link" to="/login">🔑 Login</Link>
            </li>
            <li className="nav-item">
              <Link className="nav-link" to="/logout">🔓 Logout</Link>
            </li>

          </ul>
        </div>
      </div>
    </nav>
  );
}

export default Navbar;
