import React, { useState, useEffect } from "react";
import { Link, useNavigate } from "react-router-dom";

function StageList() {
  const [stages, setStages] = useState([]);
  const navigate = useNavigate();
  const [roles, setRoles] = useState([]);

  // ✅ Fetch Stages from Backend
  useEffect(() => {
    fetchStages();

    // ✅ Get roles from localStorage
    const storedRoles = JSON.parse(localStorage.getItem("roles")) || [];
    setRoles(storedRoles);
  }, []);

  const fetchStages = () => {
    fetch("http://localhost:8080/api/stages")
      .then((response) => response.json())
      .then((data) => {
        console.log("📌 Stages loaded:", data);
        setStages(data);
      })
      .catch((error) => console.error("Error fetching stages:", error));
  };

  const isStudent = roles.includes("ROLE_ETUDIANT"); // ✅ Check if user is a student

  // ✅ Handle Delete
  const handleDelete = (id) => {
    if (window.confirm("Voulez-vous vraiment supprimer ce stage ?")) {
      fetch(`http://localhost:8080/api/stages/delete/${id}`, {
        method: "DELETE",
      })
        .then(() => {
          alert("Stage supprimé avec succès !");
          fetchStages(); // Refresh list after delete
        })
        .catch((error) => console.error("Error deleting stage:", error));
    }
  };

  // ✅ Handle Update
  const handleUpdate = (id) => {
    navigate(`/modifier-stage/${id}`);
  };

  return (
    <div className="container mt-4">
      <h2 className="mb-4">Liste des Stages</h2>

      {/* 🔹 Only Admin or Enterprise can add a stage */}
      {!isStudent && (
        <div>
          <Link to="/ajouter-stage" className="btn btn-success mt-3">
            Ajouter un stage
          </Link>
        </div>
      )}

      <br />
      
      <table className="table table-striped table-hover">
        <thead className="table-success">
          <tr>
            <th>ID</th>
            <th>Nom</th>
            <th>Description</th>
            <th>Entreprise</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {stages.map((stage) => (
            <tr key={stage.id}>
              <td>{stage.id}</td>
              <td>{stage.name}</td>
              <td>{stage.description}</td>
              <td>{stage.enterprise?.name || "Non attribué"}</td>
              <td>
                {/* 🔹 Show only "Candidater" for students */}
                {isStudent ? (
                  <button
                    className="btn btn-primary btn-sm"
                    onClick={() => navigate(`/ajouter-ma-candidature/${stage.id}`)}
                  >
                    Candidater
                  </button>
                ) : (
                  <>
                    {/* 🔹 Non-students can modify & delete */}
                    <button
                      className="btn btn-warning btn-sm me-2"
                      onClick={() => handleUpdate(stage.id)}
                    >
                      Modifier
                    </button>
                    <button
                      className="btn btn-danger btn-sm"
                      onClick={() => handleDelete(stage.id)}
                    >
                      Supprimer
                    </button>
                  </>
                )}
              </td>
            </tr>
          ))}
        </tbody>
      </table>
    </div>
  );
}

export default StageList;
