import React, { useState, useEffect } from "react";
import { useParams, useNavigate } from "react-router-dom";

function UpdateStageForm() {
  const { id } = useParams();
  const navigate = useNavigate();

  const [stage, setStage] = useState({
    name: "",
    description: "",
    enterprise: null, // Stores selected enterprise
  });

  const [enterprises, setEnterprises] = useState([]); // Stores list of enterprises

  // Fetch stage details
  useEffect(() => {
    fetch(`http://localhost:8080/api/stages/${id}`)
      .then((res) => res.json())
      .then((data) => setStage(data))
      .catch((err) => console.error("Erreur:", err));

    // Fetch enterprises for the dropdown
    fetch("http://localhost:8080/api/enterprises")
      .then((res) => res.json())
      .then((data) => setEnterprises(data))
      .catch((err) => console.error("Erreur fetching enterprises:", err));
  }, [id]);

  const handleChange = (e) => {
    setStage({ ...stage, [e.target.name]: e.target.value });
  };

  const handleEnterpriseChange = (e) => {
    const selectedEnterprise = enterprises.find((ent) => ent.id === parseInt(e.target.value));
    setStage({ ...stage, enterprise: selectedEnterprise });
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    fetch(`http://localhost:8080/api/stages/${id}`)
    .then((res) => res.json())
    .then((data) => {
      console.log("📌 Loaded stage:", data);  // ✅ Debugging Log
      setStage({
        name: data.name || "",  // ✅ Ensure name is stored
        description: data.description || "",
        enterprise: data.enterprise || null
      });
    })
    .catch((err) => console.error("Erreur:", err));
  };

  return (
    <div className="container mt-4">
      <h2>Modifier un Stage</h2>
      <form onSubmit={handleSubmit}>
        <div className="mb-3">
          <label className="form-label">Nom du stage</label>
          <input type="text" className="form-control" name="name" value={stage.name} onChange={handleChange} required />
        </div>
        <div className="mb-3">
          <label className="form-label">Description</label>
          <textarea className="form-control" name="description" value={stage.description} onChange={handleChange} required />
        </div>
        <div className="mb-3">
          <label className="form-label">Entreprise</label>
          <select className="form-control" value={stage.enterprise?.id || ""} onChange={handleEnterpriseChange} required>
            <option value="" disabled>-- Sélectionnez une entreprise --</option>
            {enterprises.map((enterprise) => (
              <option key={enterprise.id} value={enterprise.id}>
                {enterprise.name}
              </option>
            ))}
          </select>
        </div>
        <button type="submit" className="btn btn-success me-2">Modifier</button>
        <button type="button" className="btn btn-secondary" onClick={() => navigate("/stages")}>Annuler</button>
      </form>
    </div>
  );
}

export default UpdateStageForm;
