import React, { useState, useEffect } from "react";
import { Link, useNavigate } from "react-router-dom";

function StudentList() {
  const [students, setStudents] = useState([]);
  const navigate = useNavigate();
  

  // Fetch Students
  useEffect(() => {
    fetchStudents();
  }, []);

  const fetchStudents = () => {
    fetch("http://localhost:8080/api/students")
      .then((response) => response.json())
      .then((data) => setStudents(data))
      .catch((error) => console.error("Error fetching students:", error));
  };

  // Handle Delete
  const handleDelete = (id) => {
    if (window.confirm("Voulez-vous vraiment supprimer cet étudiant ?")) {
      fetch(`http://localhost:8080/api/students/delete/${id}`, {
        method: "DELETE",
      })
        .then(() => {
          alert("Étudiant supprimé avec succès !");
          fetchStudents(); // Refresh list after delete
        })
        .catch((error) => console.error("Error deleting student:", error));
    }
  };

  // Handle Update
  const handleUpdate = (id) => {
    navigate(`/modifier-etudiant/${id}`);
  };

  return (
    <div className="container mt-4">
      <h2 className="mb-4">Liste des Étudiants</h2>
      <div>
        <Link to="/ajouter-etudiant" className="btn btn-success mt-3">
        Ajouter un(e) étudiant(e)
        </Link>
      </div>
      <br />
      <table className="table table-striped table-hover">
        <thead className="table-info">
          <tr>
            <th>ID</th>
            <th>Prénom</th>
            <th>Nom</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {students.map((student) => (
            <tr key={student.id}>
              <td>{student.id}</td>
              <td>{student.firstname}</td>
              <td>{student.lastname}</td>
              <td>
                <button
                  className="btn btn-warning btn-sm me-2"
                  onClick={() => handleUpdate(student.id)}
                >
                  Modifier
                </button>
                <button
                  className="btn btn-danger btn-sm"
                  onClick={() => handleDelete(student.id)}
                >
                  Supprimer
                </button>
              </td>
            </tr>
          ))}
        </tbody>
      </table>
    </div>
  );
}

export default StudentList;
