import React, { useState, useEffect } from "react";
import { useParams, useNavigate } from "react-router-dom";

function UpdateStudentForm() {
  const { id } = useParams();
  const navigate = useNavigate();

  const [student, setStudent] = useState({
    firstname: "",
    lastname: "",
  });

  useEffect(() => {
    fetch(`http://localhost:8080/api/students/${id}`)
      .then((res) => res.json())
      .then((data) => setStudent(data))
      .catch((err) => console.error("Erreur de chargement:", err));
  }, [id]);

  const handleChange = (e) => {
    setStudent({ ...student, [e.target.name]: e.target.value });
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    fetch(`http://localhost:8080/api/students/${id}`, {
      method: "PUT",
      headers: { "Content-Type": "application/json" },
      body: JSON.stringify(student),
    })
      .then(() => {
        alert("Étudiant mis à jour !");
        navigate("/etudiants");
      })
      .catch((err) => console.error("Erreur:", err));
  };

   // Handle cancel button
   const handleCancel = () => {
    navigate("/entreprises"); // Redirect back to candidacy list
  };

  return (
    <div className="container mt-4">
      <h2>Modifier un Étudiant</h2>
      <form onSubmit={handleSubmit}>
        <div className="mb-3">
          <label className="form-label">Prénom</label>
          <input type="text" className="form-control" name="firstname" value={student.firstname} onChange={handleChange} required />
        </div>
        <div className="mb-3">
          <label className="form-label">Nom</label>
          <input type="text" className="form-control" name="lastname" value={student.lastname} onChange={handleChange} required />
        </div>
        {/* Buttons: Update & Cancel */}
        <div className="d-flex gap-2">
          <button type="submit" className="btn btn-success">Mettre à jour</button>
          <button type="button" className="btn btn-secondary" onClick={handleCancel}>Annuler</button>
        </div>
      </form>
    </div>
  );
}

export default UpdateStudentForm;
