import React, { useState, useEffect } from "react";
import { Link } from "react-router-dom";

function UnivSupervisorList() {
  const [univSupervisors, setUnivSupervisors] = useState([]);

  useEffect(() => {
    fetch("http://localhost:8080/api/univsupervisors")
      .then((response) => response.json())
      .then((data) => setUnivSupervisors(data))
      .catch((error) => console.error("Error fetching university supervisors:", error));
  }, []);

  const handleDelete = (id) => {
    if (window.confirm("Voulez-vous vraiment supprimer ce superviseur universitaire ?")) {
      fetch(`http://localhost:8080/api/univsupervisors/${id}`, {
        method: "DELETE",
      })
        .then(() => {
          alert("Superviseur supprimé !");
          setUnivSupervisors(univSupervisors.filter((supervisor) => supervisor.id !== id));
        })
        .catch((error) => console.error("Erreur lors de la suppression :", error));
    }
  };

  return (
    <div className="container mt-4">
      <div className="d-flex justify-content-between align-items-center mb-3">
        <h2>Liste des Superviseurs Universitaires</h2>
        <Link to="/ajouter-univsuperviseur" className="btn btn-success">
          Ajouter un Superviseur
        </Link>
      </div>
      
      <table className="table table-striped table-hover">
        <thead className="table-primary">
          <tr>
            <th>ID</th>
            <th>Nom</th>
            <th>Stages Supervisés</th>
            <th>Actions</th>
          </tr>
        </thead>
        <tbody>
          {univSupervisors.map((supervisor) => (
            <tr key={supervisor.id}>
              <td>{supervisor.id}</td>
              <td>{supervisor.name}</td>
              <td>
                {supervisor.supervisedStages && supervisor.supervisedStages.length > 0 ? (
                    <ul className="list-unstyled">
                    {supervisor.supervisedStages.map((candidacy) => (
                        <li key={candidacy.id}>
                        {candidacy.stage?.name || "Nom du stage indisponible"}
                        </li>
                    ))}
                    </ul>
                ) : (
                    <span className="text-muted">Aucun stage</span>
                )}
                </td>

              <td>
                <Link to={`/modifier-univsuperviseur/${supervisor.id}`} className="btn btn-warning btn-sm me-2">
                  Modifier
                </Link>
                <button onClick={() => handleDelete(supervisor.id)} className="btn btn-danger btn-sm">
                  Supprimer
                </button>
              </td>
            </tr>
          ))}
        </tbody>
      </table>
    </div>
  );
}

export default UnivSupervisorList;
